class Image < ApplicationRecord
  belongs_to :user
  has_many :image_tags, dependent: :destroy
  has_many :tags, through: :image_tags

  has_one_attached :file

  validates :title, presence: true
  validates :file, presence: true, on: :create

  # Status for review process
  # enum status: { pending: 0, approved: 1, rejected: 2 }, _default: :pending

  # Scopes for filtering
  scope :pending, -> { where(status: :pending) }
  scope :approved, -> { where(status: :approved) }
  scope :rejected, -> { where(status: :rejected) }

  # Method to add tags to an image
  def add_tags(tag_names)
    tag_names.each do |name|
      tag = Tag.find_or_create_by(name: name.downcase.strip)
      tags << tag unless tags.include?(tag)
    end
  end
end
